@@ -134,7 +134,16 @@ rotate_crs <- function(crs, meridians) {
   
   ## CRS rotation
   
-  tmp <- unlist(strsplit(sf::st_crs(crs)$proj4string, " "))
+  crs_info <- sf::st_crs(crs)
+  crs_input <- crs_info$input
+  if(is.null(crs_input) || is.na(crs_input) || !nzchar(crs_input) || !grepl("\\+proj", crs_input)) {
+    crs_input <- suppressWarnings(crs_info$proj4string)
+  }
+  if(is.null(crs_input) || is.na(crs_input) || !nzchar(crs_input)) {
+    stop("crs does not have a PROJ string representation.")
+  }
+  
+  tmp <- unlist(strsplit(crs_input, " "))
   
   if(any(grepl("lon_0=", tmp))) {
     tmp[grepl("lon_0=", tmp)] <- paste0("lon_0=", midLon)
@@ -143,9 +152,6 @@ rotate_crs <- function(crs, meridians) {
   }
   
   sf::st_crs(paste(tmp, collapse = " "))
-  
-  
-  
 }
 
 #' @title Create clip boundary from decimal degree limits
@@ -190,7 +196,11 @@ dd_clip_boundary <- function(limits, crs, expand.factor = NULL) {
   
   midLon <- tmp[1] + lonDiff/2
   
-  tmp <- deg_to_dd(c(tmp[1], midLon, tmp[2]))
+  if (limits[1] > limits[2]) {
+    tmp <- c(tmp[1], midLon, tmp[2])
+  } else {
+    tmp <- deg_to_dd(c(tmp[1], midLon, tmp[2]))
+  }
   
   coords <- data.frame(
     lon = c(tmp, rev(tmp), tmp[1]), 
