@@ -8,14 +8,14 @@
 #' @family customize shapefiles
 #' @export
 
-theme_map <- function(..., grid.col, grid.size) {
-    theme_bw(...) %+replace%
+theme_map <- function(..., grid.col = NULL, grid.size = NULL) {
+    theme_bw(...) +
       theme(panel.background = element_blank(),
-      panel.border = element_rect(fill = NA, colour = "black", size = 0.2),
+      panel.border = element_rect(fill = NA, colour = "black", linewidth = 0.2),
       panel.grid = element_line(colour = grid.col, linewidth = grid.size),
       plot.background = element_blank(),
-      axis.ticks.x = element_line(colour = "black", size = 0.2),
-      axis.ticks.y = element_line(colour = "black", size = 0.2),
+      axis.ticks.x = element_line(colour = "black", linewidth = 0.2),
+      axis.ticks.y = element_line(colour = "black", linewidth = 0.2),
       axis.line.x = element_blank(),
       axis.line.y = element_blank(),
       panel.ontop = TRUE
